# SpacePass

## Description
SpacePass is a [spacemacs](http://spacemacs.org) inspired gui for [pass](https://www.passwordstore.org) 
It was designed to be used in i3wm but should work on another DE/WM

## Dependencies
[pass](https://www.passwordstore.org)
gtk-3.0

## Installation
```bash
pip install spacepass
```

## Usage
### i3wm
bindsym the desired
```
bindsym $mod+Shift+p exec spacepass
```

## Configuration
Configuration is read from the config file 

## TODO


## License
GPL-3.0-or-later 
